@@ -8,6 +8,7 @@ import (
 	"errors"
 	"fmt"
 	"os"
+	"regexp"
 	"testing"
 
 	"github.com/docker/docker/api/types"
@@ -37,15 +38,15 @@ func TestDockerForNamedImage(t *testing.T) {
 
 	m := newDefaultTestManager(c, dockerConfig)
 
-	c.On("ImagePullBlocking", m.context, "test:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "test:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(os.ErrNotExist).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "tagged:tag", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "tagged:tag", mock.AnythingOfType("image.PullOptions")).
 		Return(os.ErrNotExist).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, validSHA, mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, validSHA, mock.AnythingOfType("image.PullOptions")).
 		Return(os.ErrNotExist).
 		Once()
 
@@ -79,7 +80,7 @@ func TestDockerForImagePullFailures(t *testing.T) {
 		"ImagePullBlocking unwrapped system failure": {
 			imageName: "unwrapped-system:failure",
 			initMock: func(c *docker.MockClient, imageName string) {
-				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("ImagePullOptions")).
+				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("image.PullOptions")).
 					Return(errdefs.System(errTest)).
 					Once()
 			},
@@ -95,7 +96,7 @@ func TestDockerForImagePullFailures(t *testing.T) {
 		"ImagePullBlocking wrapped system failure": {
 			imageName: "wrapped-system:failure",
 			initMock: func(c *docker.MockClient, imageName string) {
-				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("ImagePullOptions")).
+				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("image.PullOptions")).
 					Return(fmt.Errorf("wrapped error: %w", errdefs.System(errTest))).
 					Once()
 			},
@@ -111,7 +112,7 @@ func TestDockerForImagePullFailures(t *testing.T) {
 		"ImagePullBlocking two level wrapped system failure": {
 			imageName: "two-level-wrapped-system:failure",
 			initMock: func(c *docker.MockClient, imageName string) {
-				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("ImagePullOptions")).
+				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("image.PullOptions")).
 					Return(fmt.Errorf("wrapped error: %w", fmt.Errorf("wrapped error: %w", errdefs.System(errTest)))).
 					Once()
 			},
@@ -127,7 +128,7 @@ func TestDockerForImagePullFailures(t *testing.T) {
 		"ImagePullBlocking wrapped request timeout failure": {
 			imageName: "wrapped-request-timeout:failure",
 			initMock: func(c *docker.MockClient, imageName string) {
-				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("ImagePullOptions")).
+				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("image.PullOptions")).
 					Return(fmt.Errorf(
 						"wrapped error: %w", errdefs.System(errors.New(
 							"request canceled while waiting for connection",
@@ -146,7 +147,7 @@ func TestDockerForImagePullFailures(t *testing.T) {
 		"ImagePullBlocking two level wrapped request timeout failure": {
 			imageName: "lwo-level-wrapped-request-timeout:failure",
 			initMock: func(c *docker.MockClient, imageName string) {
-				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("ImagePullOptions")).
+				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("image.PullOptions")).
 					Return(fmt.Errorf(
 						"wrapped error: %w", fmt.Errorf(
 							"wrapped error: %w", errdefs.System(errors.New(
@@ -166,7 +167,7 @@ func TestDockerForImagePullFailures(t *testing.T) {
 		"ImagePullBlocking unwrapped script failure": {
 			imageName: "unwrapped-script:failure",
 			initMock: func(c *docker.MockClient, imageName string) {
-				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("ImagePullOptions")).
+				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("image.PullOptions")).
 					Return(errdefs.NotFound(errTest)).
 					Once()
 			},
@@ -182,7 +183,7 @@ func TestDockerForImagePullFailures(t *testing.T) {
 		"ImagePullBlocking wrapped script failure": {
 			imageName: "wrapped-script:failure",
 			initMock: func(c *docker.MockClient, imageName string) {
-				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("ImagePullOptions")).
+				c.On("ImagePullBlocking", m.context, imageName, mock.AnythingOfType("image.PullOptions")).
 					Return(fmt.Errorf("wrapped error: %w", errdefs.NotFound(errTest))).
 					Once()
 			},
@@ -212,7 +213,7 @@ func TestDockerForExistingImage(t *testing.T) {
 	dockerConfig := &common.DockerConfig{}
 	dockerOptions := common.ImageDockerOptions{}
 	m := newDefaultTestManager(c, dockerConfig)
-	c.On("ImagePullBlocking", m.context, "existing:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "existing:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(nil).
 		Once()
 
@@ -315,7 +316,7 @@ func TestDockerPolicyModeIfNotPresentForNotExistingImage(t *testing.T) {
 		Return(types.ImageInspect{}, nil, os.ErrNotExist).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "not-existing:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "not-existing:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(nil).
 		Once()
 
@@ -353,7 +354,7 @@ func TestDockerPolicyModeAlwaysForExistingImage(t *testing.T) {
 		Return(types.ImageInspect{ID: "image-id"}, nil, nil).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "existing:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "existing:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(nil).
 		Once()
 
@@ -382,7 +383,7 @@ func TestDockerPolicyModeAlwaysForLocalOnlyImage(t *testing.T) {
 		Return(types.ImageInspect{ID: "image-id"}, nil, nil).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "existing:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "existing:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(fmt.Errorf("not found")).
 		Once()
 
@@ -404,7 +405,7 @@ func TestDockerGetExistingDockerImageIfPullFails(t *testing.T) {
 		Return(types.ImageInspect{ID: "image-id"}, nil, nil).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "to-pull:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "to-pull:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(os.ErrNotExist).
 		Once()
 
@@ -416,7 +417,7 @@ func TestDockerGetExistingDockerImageIfPullFails(t *testing.T) {
 		Return(types.ImageInspect{}, nil, os.ErrNotExist).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "not-existing:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "not-existing:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(os.ErrNotExist).
 		Once()
 
@@ -442,7 +443,7 @@ func TestCombinedDockerPolicyModesAlwaysAndIfNotPresentForExistingImage(t *testi
 		Return(types.ImageInspect{ID: "image-id"}, nil, nil).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "existing:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "existing:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(errors.New("received unexpected HTTP status: 502 Bad Gateway")).
 		Once()
 
@@ -472,7 +473,7 @@ func TestCombinedDockerPolicyModeAlwaysAndIfNotPresentForNonExistingImage(t *tes
 		Return(types.ImageInspect{}, nil, os.ErrNotExist).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "not-existing:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "not-existing:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(os.ErrNotExist).
 		Twice()
 
@@ -552,7 +553,7 @@ func TestPullPolicyPassedAsIfNotPresentForNonExistingAndConfigAlways(t *testing.
 		Return(types.ImageInspect{}, nil, os.ErrNotExist).
 		Once()
 
-	c.On("ImagePullBlocking", m.context, "not-existing:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "not-existing:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(nil).
 		Once()
 
@@ -583,11 +584,7 @@ func TestPullPolicyPassedAsIfNotPresentButNotAllowedDefault(t *testing.T) {
 		err.Error(),
 		`invalid pull policy for image "existing"`,
 	)
-	assert.Contains(
-		t,
-		err.Error(),
-		fmt.Sprintf(common.IncompatiblePullPolicy, "[if-not-present]", "GitLab pipeline config", "[always]"),
-	)
+	assert.Regexp(t, regexp.MustCompile(`if-not-present.* GitLab pipeline config .*always`), err.Error())
 }
 
 func TestPullPolicyPassedAsIfNotPresentButNotAllowed(t *testing.T) {
@@ -608,11 +605,7 @@ func TestPullPolicyPassedAsIfNotPresentButNotAllowed(t *testing.T) {
 		err.Error(),
 		`invalid pull policy for image "existing"`,
 	)
-	assert.Contains(
-		t,
-		err.Error(),
-		fmt.Sprintf(common.IncompatiblePullPolicy, "[if-not-present]", "GitLab pipeline config", "[never]"),
-	)
+	assert.Regexp(t, regexp.MustCompile(`if-not-present.* GitLab pipeline config .*never`), err.Error())
 }
 
 func TestPullPolicyWhenConfigIsNotAllowed(t *testing.T) {
@@ -633,11 +626,7 @@ func TestPullPolicyWhenConfigIsNotAllowed(t *testing.T) {
 		err.Error(),
 		`invalid pull policy for image "existing"`,
 	)
-	assert.Contains(
-		t,
-		err.Error(),
-		fmt.Sprintf(common.IncompatiblePullPolicy, "[never if-not-present]", "Runner config", "[always]"),
-	)
+	assert.Regexp(t, regexp.MustCompile(`never if-not-present.* Runner config .*always`), err.Error())
 }
 
 func TestPullPolicyWhenConfigIsAllowed(t *testing.T) {
@@ -711,6 +700,7 @@ func newLoggerMock() *mockPullLogger {
 	).Maybe()
 	loggerMock.On("Infoln", mock.AnythingOfType("string")).Maybe()
 	loggerMock.On("Warningln", mock.AnythingOfType("string")).Maybe()
+	loggerMock.On("Println", mock.AnythingOfType("string"), mock.Anything).Maybe()
 	loggerMock.On(
 		"Println",
 		mock.AnythingOfType("string"),
@@ -796,7 +786,7 @@ func addPullsRemoteImageExpectations(c *docker.MockClient, imageName string) {
 		Return(types.ImageInspect{ID: "not-this-image"}, nil, nil).
 		Once()
 
-	c.On("ImagePullBlocking", mock.Anything, imageName, mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", mock.Anything, imageName, mock.AnythingOfType("image.PullOptions")).
 		Return(nil).
 		Once()
 
@@ -810,7 +800,7 @@ func addDeniesPullExpectations(c *docker.MockClient, imageName string) {
 		Return(types.ImageInspect{ID: "image"}, nil, nil).
 		Once()
 
-	c.On("ImagePullBlocking", mock.Anything, imageName, mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", mock.Anything, imageName, mock.AnythingOfType("image.PullOptions")).
 		Return(fmt.Errorf("deny pulling")).
 		Once()
 }
@@ -870,7 +860,7 @@ func TestDockerGetImagePlatformSuccess(t *testing.T) {
 
 	m := newDefaultTestManager(c, dockerConfig)
 
-	c.On("ImagePullBlocking", m.context, "test:latest", mock.AnythingOfType("ImagePullOptions")).
+	c.On("ImagePullBlocking", m.context, "test:latest", mock.AnythingOfType("image.PullOptions")).
 		Return(nil).
 		Once()
 
