@@ -28,9 +28,9 @@ const (
 	UseAdvancedPodSpecConfiguration      string = "FF_USE_ADVANCED_POD_SPEC_CONFIGURATION"
 	SetPermissionsBeforeCleanup          string = "FF_SET_PERMISSIONS_BEFORE_CLEANUP"
 	EnableSecretResolvingFailsIfMissing  string = "FF_SECRET_RESOLVING_FAILS_IF_MISSING"
-	RetrievePodWarningEvents             string = "FF_RETRIEVE_POD_WARNING_EVENTS"
 	PrintPodEvents                       string = "FF_PRINT_POD_EVENTS"
 	UseGitBundleURIs                     string = "FF_USE_GIT_BUNDLE_URIS"
+	UseGitNativeClone                    string = "FF_USE_GIT_NATIVE_CLONE"
 	UseDumbInitWithKubernetesExecutor    string = "FF_USE_DUMB_INIT_WITH_KUBERNETES_EXECUTOR"
 	UseInitWithDockerExecutor            string = "FF_USE_INIT_WITH_DOCKER_EXECUTOR"
 	LogImagesConfiguredForJob            string = "FF_LOG_IMAGES_CONFIGURED_FOR_JOB"
@@ -48,6 +48,8 @@ const (
 	MaskAllDefaultTokens                 string = "FF_MASK_ALL_DEFAULT_TOKENS"
 	ExportHighCardinalityMetrics         string = "FF_EXPORT_HIGH_CARDINALITY_METRICS"
 	UseFleetingAcquireHeartbeats         string = "FF_USE_FLEETING_ACQUIRE_HEARTBEATS"
+	UseExponentialBackoffStageRetry      string = "FF_USE_EXPONENTIAL_BACKOFF_STAGE_RETRY"
+	UseAdaptiveRequestConcurrency        string = "FF_USE_ADAPTIVE_REQUEST_CONCURRENCY"
 )
 
 type FeatureFlag struct {
@@ -259,15 +261,6 @@ var flags = []FeatureFlag{
 		Deprecated:   false,
 		Description:  "When enabled, secret resolving fails if the value cannot be found.",
 	},
-	{
-		Name:         RetrievePodWarningEvents,
-		DefaultValue: true,
-		Deprecated:   true,
-		Description: "When enabled, all warning events associated with the pod are retrieved when the job fails. " +
-			"This flag was deprecated in GitLab Runner 17.2 and is planned for removal in 18.0. " +
-			"In GitLab Runner 17.2 and later, pod warning events are retrieved and logged unconditionally. " +
-			"However, no failure occurs even if RBAC permissions are missing.",
-	},
 	{
 		Name:         PrintPodEvents,
 		DefaultValue: false,
@@ -281,6 +274,14 @@ var flags = []FeatureFlag{
 		Description: "When enabled, the Git `transfer.bundleURI` configuration option is set to `true`. This FF is enabled by default. " +
 			"Set to `false` to disable Git bundle support.",
 	},
+	{
+		Name:         UseGitNativeClone,
+		DefaultValue: false,
+		Deprecated:   false,
+		Description: "When enabled and `GIT_STRATEGY=clone`, the `git-clone(1)` command is used instead of `git-init(1)` + `git-fetch(1)` to clone the project. " +
+			"This requires Git version 2.49 and later, and falls back to `init` + `fetch` if not available.",
+	},
+
 	{
 		Name:         UseDumbInitWithKubernetesExecutor,
 		DefaultValue: false,
@@ -365,7 +366,7 @@ var flags = []FeatureFlag{
 		Deprecated:   false,
 		Description: "When enabled, GitLab Runner doesn't embed the job token anywhere during Git configuration or command " +
 			"execution. Instead, it sets up a Git credential helper that uses the environment variable to obtain the job token. " +
-			"This approach limits token storage and reduces the potential for leaks.",
+			"This approach limits token storage and reduces the risk of token leaks.",
 	},
 	{
 		Name:         WaitForPodReachable,
@@ -375,7 +376,7 @@ var flags = []FeatureFlag{
 	},
 	{
 		Name:         UseNativeSteps,
-		DefaultValue: false,
+		DefaultValue: true,
 		Deprecated:   false,
 		Description: "When enabled and when a job is specified using the 'run' keyword, steps are executed using " +
 			"[Native Step Runner Integration](../executors/docker.md#native-step-runner-integration). " +
@@ -400,6 +401,20 @@ var flags = []FeatureFlag{
 		Deprecated:   false,
 		Description:  "When enabled, fleeting instance connectivity is checked before a job is assigned to an instance.",
 	},
+	{
+		Name:         UseExponentialBackoffStageRetry,
+		DefaultValue: true,
+		Deprecated:   false,
+		Description: "When enabled, the retries for `GET_SOURCES_ATTEMPTS`, `ARTIFACT_DOWNLOAD_ATTEMPTS`, `RESTORE_CACHE_ATTEMPTS`, and `EXECUTOR_JOB_SECTION_ATTEMPTS` " +
+			"use exponential backoff (5 sec - 5 min).",
+	},
+	{
+		Name:         UseAdaptiveRequestConcurrency,
+		DefaultValue: true,
+		Deprecated:   false,
+		Description: "When enabled, the `request_concurrency` setting becomes the maximum concurrency value, and the number of concurrent requests adjusts based on the " +
+			"rate of successful job requests.",
+	},
 }
 
 func GetAll() []FeatureFlag {
