@@ -11,6 +11,7 @@ import (
 	"strconv"
 	"strings"
 	"time"
+	"unicode"
 
 	"gitlab.com/gitlab-org/gitlab-runner/cache"
 	"gitlab.com/gitlab-org/gitlab-runner/common"
@@ -77,9 +78,13 @@ func (b *AbstractShell) cacheFile(build *common.Build, userKey string) (string,
 	}
 
 	// Deduce cache key
-	key := path.Join(build.JobInfo.Name, build.GitInfo.Ref)
+	var key string
 	if userKey != "" {
 		key = build.GetAllVariables().ExpandValue(userKey)
+	} else {
+		// we root the path, to not have path traversal issues
+		path := path.Join("/", build.JobInfo.Name, build.GitInfo.Ref)
+		key = path[1:]
 	}
 
 	// Ignore cache without the key
@@ -181,20 +186,38 @@ func (b *AbstractShell) extractCacheOrFallbackCachesWrapper(
 	cacheKey string,
 	cacheOptions common.Cache,
 ) {
-	allowedCacheKeys := []string{cacheKey}
+	allowedCacheKeys := []string{}
 
-	for _, cacheKey := range cacheOptions.FallbackKeys {
-		if cacheKey != "" {
-			allowedCacheKeys = append(allowedCacheKeys, info.Build.GetAllVariables().ExpandValue(cacheKey))
+	buildVars := info.Build.GetAllVariables()
+	addCacheKey := func(key string, err error) {
+		if key != "" {
+			allowedCacheKeys = append(allowedCacheKeys, key)
+		}
+		if err != nil {
+			w.Warningf(err.Error())
 		}
 	}
 
-	// We make sure that the CACHE_FALLBACK_KEY doesn't end with characters like space, slash and backslash
-	// TrimRight remove all occurrences of those character at the end of the fallback key
-	defaultFallbackCacheKey := sanitizeCacheFallbackKey(info.Build.GetAllVariables().Value("CACHE_FALLBACK_KEY"))
-	if defaultFallbackCacheKey != "" && !strings.HasSuffix(defaultFallbackCacheKey, "-protected") {
-		// The `-protected` suffix is reserved for protected refs, so we disallow it in the global variable.
-		allowedCacheKeys = append(allowedCacheKeys, defaultFallbackCacheKey)
+	// the "default" cache key
+	addCacheKey(sanitizeCacheKey(cacheKey))
+
+	// the fallback cache keys from the cache config
+	for _, cacheKey := range cacheOptions.FallbackKeys {
+		addCacheKey(sanitizeCacheKey(buildVars.ExpandValue(cacheKey)))
+	}
+
+	// the fallback key from CACHE_FALLBACK_KEY
+	// we sanitize it and check if it's not pointing to a protected cache.
+	fallbackCacheKey, err := sanitizeCacheKey(buildVars.Value("CACHE_FALLBACK_KEY"))
+	blockedSuffix := "-protected"
+	if !strings.HasSuffix(fallbackCacheKey, blockedSuffix) {
+		addCacheKey(fallbackCacheKey, err)
+	} else {
+		w.Warningf("CACHE_FALLBACK_KEY %q not allowed to end in %q", fallbackCacheKey, blockedSuffix)
+	}
+
+	if len(allowedCacheKeys) < 1 {
+		return
 	}
 
 	// Execute cache-extractor command. Failure is not fatal.
@@ -203,8 +226,70 @@ func (b *AbstractShell) extractCacheOrFallbackCachesWrapper(
 	})
 }
 
-func sanitizeCacheFallbackKey(fallbackKey string) string {
-	return strings.TrimRight(fallbackKey, " /\\")
+// sanitizeCacheKey replicates some cache key rules from GitLab and adds additional validations for known-bad cache
+// keys.
+// It accepts that the cache keys can be paths and:
+//   - replaces the URL encoded version of `/` & `.` with their ASCII ones
+//   - replaces all `\` with `/`
+//   - ensures there are no path traversals possible "outside of the base path"
+//   - ensures the last path element is not empty or ends in a space
+func sanitizeCacheKey(cacheKey string) (sanitizedKey string, err error) {
+	if cacheKey == "" {
+		return "", nil
+	}
+
+	replaceEncodedSlashes := func(s string) string {
+		for _, slash := range []string{"%2f", "%2F"} {
+			s = strings.ReplaceAll(s, slash, "/")
+		}
+		return s
+	}
+	replaceEncodedDots := func(s string) string {
+		for _, dot := range []string{"%2e", "%2E"} {
+			s = strings.ReplaceAll(s, dot, ".")
+		}
+		return s
+	}
+	toSlash := func(s string) string {
+		return strings.ReplaceAll(s, `\`, `/`)
+	}
+	trimSpaceRight := func(s string) string {
+		return strings.TrimRightFunc(s, unicode.IsSpace)
+	}
+
+	// We root the path, so that path traversals outside of the base path, e.g. resulting in a key like `../../foo/bar`,
+	// aren't possible
+	// Note: path.Join calls path.Clean internally
+	cleaned := path.Join(
+		"/", toSlash(replaceEncodedSlashes(replaceEncodedDots(cacheKey))),
+	)
+
+	var key string
+	for {
+		if cleaned == "" {
+			break
+		}
+
+		dir, file := path.Split(cleaned)
+		file = trimSpaceRight(file)
+
+		if file == "" {
+			cleaned = dir[:len(dir)-1] // cut off the trailing `/` from dir and continue with that
+			continue
+		}
+
+		key = path.Join(dir[1:], file) // cut off the leading `/` from dir, because we rooted the path initially
+		break
+	}
+
+	if key == "" {
+		return "", fmt.Errorf("cache key %q could not be sanitized", cacheKey)
+	}
+	if key != cacheKey {
+		return key, fmt.Errorf("cache key %q sanitized to %q", cacheKey, key)
+	}
+
+	return key, nil
 }
 
 func (b *AbstractShell) addExtractCacheCommand(
@@ -1160,6 +1245,15 @@ func (b *AbstractShell) archiveCache(
 			w.Noticef("Skipping cache archiving due to %v", err)
 			continue
 		}
+		// we also want to sanitize the cache key on upload, so that we actually use the same keys on up and download, ie.
+		// it round-trips
+		cacheKey, err = sanitizeCacheKey(cacheKey)
+		if err != nil {
+			w.Warningf(err.Error())
+		}
+		if cacheKey == "" {
+			continue
+		}
 
 		cacheOptions.Policy = common.CachePolicy(info.Build.GetAllVariables().ExpandValue(string(cacheOptions.Policy)))
 
